@@ -1,4 +1,7 @@
+import logging
+
 testinfra_hosts = ['ansible://infrastructure2-host']
+logger = logging.getLogger(__name__)
 
 
 def test_infrastructure2_encrypted_volume(host):
@@ -10,8 +13,8 @@ def test_infrastructure2_encrypted_volume(host):
     test -e /opt/snap/hello-world
     grep -q snap /etc/fstab
     """)
-    print(cmd.stdout)
-    print(cmd.stderr)
+    logger.debug('stdout %s', cmd.stdout)
+    logger.debug('stderr %s', cmd.stderr)
     assert 0 == cmd.rc
 
     # set by infrastructure/test-encrypted-volume.yml
