@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'wekan-host')
-        assert r['attrs']['name'] == 'wekan-host'
+        assert 'wekan-host' in self.get_hosts(host='wekan-host')
 
     def test_service(self):
         assert self.is_service_ok('wekan-host!Wekan')
