@@ -154,14 +154,22 @@ class InfrastructureLibvirt(Infrastructure):
 
     def mock(self, mocker):
         port = '22'
-        global_variables = {
+        network_global_variables = {
             'libvirt_network_external_name': f'{self.prefix}e',
             'libvirt_network_external_prefix': '10.123.43',
             'libvirt_network_internal_name': f'{self.prefix}i',
             'libvirt_network_internal_prefix': '10.4.5',
         }
+
+        def get_global_variable(name):
+            if name == 'libvirt_uri':
+                return 'qemu:///system'
+            elif name == 'libvirt_ssh':
+                return []
+            else:
+                return network_global_variables
         mocker.patch('enough.common.ansible_utils.Ansible.get_global_variable',
-                     return_value=global_variables)
+                     side_effect=get_global_variable)
         definitions = {
             self.prefix: {
                 'name': self.prefix,
@@ -172,7 +180,7 @@ class InfrastructureLibvirt(Infrastructure):
                 'network_interface_not_routed': 'enp2s0',
             },
         }
-        definitions[self.prefix].update(global_variables)
+        definitions[self.prefix].update(network_global_variables)
         mocker.patch('enough.common.libvirt.Libvirt.get_definitions',
                      return_value=definitions)
 
