@@ -7,9 +7,9 @@ from tests import prepare_config_dir
 
 
 @pytest.mark.openstack_integration
-def test_ssh(openstack_name, openstack_provider, tmpdir):
+def test_ssh(openstack_name, openstack_variables, tmpdir):
     domain = 'enough.community'
-    d = Heat.hostvars_to_stack(openstack_name, openstack_provider)
+    d = Heat.hostvars_to_stack(openstack_name, openstack_variables)
     config_dir = prepare_config_dir(domain, tmpdir)
     ssh = SSH(config_dir, domain=domain)
     s = Stack(config_dir, d)
