@@ -77,7 +77,7 @@ class IcingaHelper(object):
         if host:
             url += f'/objects/hosts/{host}?attrs=name&attrs=state'
         else:
-            url += f'/objects/hosts?attrs=name&attrs=state'
+            url += '/objects/hosts?attrs=name&attrs=state'
 
         answer = requests.get(url, **self.connection_params())
         answer.raise_for_status()
